@@ -109,7 +109,7 @@ class EnhancedStreamProcessor:
             'metrics_update_interval': 10.0
         }
         
-        log.info(f"Enhanced stream processor initialized with {max_workers} workers")
+        log.debug(f"Enhanced stream processor initialized with {max_workers} workers")
     
     async def start(self) -> bool:
         """
@@ -119,7 +119,7 @@ class EnhancedStreamProcessor:
             bool: True if started successfully
         """
         try:
-            log.info("Starting enhanced stream processor...")
+            log.debug("Starting enhanced stream processor...")
             
             self.workers_running = True
             
@@ -138,7 +138,10 @@ class EnhancedStreamProcessor:
             batch_task = asyncio.create_task(self._batch_processor_loop())
             self.worker_tasks.append(batch_task)
             
-            log.info(f"Started {len(self.worker_tasks)} worker tasks")
+            # Start tunnel telemetry collection parallel to stream processing
+            await self._start_tunnel_telemetry_collection()
+            
+            log.debug(f"Started {len(self.worker_tasks)} worker tasks")
             return True
             
         except Exception as e:
@@ -147,7 +150,7 @@ class EnhancedStreamProcessor:
     
     async def stop(self) -> None:
         """Stop the enhanced stream processor."""
-        log.info("Stopping enhanced stream processor...")
+        log.debug("Stopping enhanced stream processor...")
         
         self.workers_running = False
         
@@ -162,7 +165,10 @@ class EnhancedStreamProcessor:
         # Shutdown executor
         self.executor.shutdown(wait=True)
         
-        log.info("Enhanced stream processor stopped")
+        # Stop tunnel telemetry collection
+        await self._stop_tunnel_telemetry_collection()
+        
+        log.debug("Enhanced stream processor stopped")
     
     async def process_transaction(
         self, 
@@ -214,7 +220,7 @@ class EnhancedStreamProcessor:
         Args:
             worker_id: Unique identifier for this worker
         """
-        log.info(f"Worker {worker_id} started")
+        log.debug(f"Worker {worker_id} started")
         
         while self.workers_running:
             try:
@@ -234,13 +240,13 @@ class EnhancedStreamProcessor:
                 self.event_queue.task_done()
                 
             except asyncio.CancelledError:
-                log.info(f"Worker {worker_id} cancelled")
+                log.debug(f"Worker {worker_id} cancelled")
                 break
             except Exception as e:
                 log.error(f"Worker {worker_id} error: {e}")
                 await asyncio.sleep(1.0)
         
-        log.info(f"Worker {worker_id} stopped")
+        log.debug(f"Worker {worker_id} stopped")
     
     async def _process_transaction_event(
         self, 
@@ -257,7 +263,7 @@ class EnhancedStreamProcessor:
         start_time = time.time()
         
         try:
-            log.info(f"Worker {worker_id} processing transaction {event.transaction.txid}")
+            log.debug(f"Worker {worker_id} processing transaction {event.transaction.txid}")
             
             # Update event status
             event.status = ProcessingStatus.PROCESSING
@@ -320,7 +326,7 @@ class EnhancedStreamProcessor:
             event.status = ProcessingStatus.COMPLETED
             await self._trigger_callbacks('processing_completed', event)
             
-            log.info(f"Transaction {event.transaction.txid} processed successfully in {processing_time:.2f}s")
+            log.debug(f"Transaction {event.transaction.txid} processed successfully in {processing_time:.2f}s")
             
         except Exception as e:
             log.error(f"Failed to process transaction {event.transaction.txid}: {e}")
@@ -336,7 +342,7 @@ class EnhancedStreamProcessor:
                     self.config['retry_delay_base'] ** event.retry_count
                 )
                 
-                log.info(f"Retrying transaction {event.transaction.txid} in {delay}s (attempt {event.retry_count})")
+                log.debug(f"Retrying transaction {event.transaction.txid} in {delay}s (attempt {event.retry_count})")
                 
                 # Re-queue with delay
                 await asyncio.sleep(delay)
@@ -361,7 +367,7 @@ class EnhancedStreamProcessor:
             decrypted_data: Decrypted transaction data
             event: Transaction event being processed
         """
-        log.info(f"Processing network event for transaction {event.transaction.txid}")
+        log.debug(f"Processing network event for transaction {event.transaction.txid}")
         # Placeholder for network event processing
         # Add your network-specific logic here
         pass
@@ -401,7 +407,7 @@ class EnhancedStreamProcessor:
         """
         Background loop for batch processing optimization.
         """
-        log.info("Batch processor loop started")
+        log.debug("Batch processor loop started")
         
         while self.workers_running:
             try:
@@ -415,19 +421,19 @@ class EnhancedStreamProcessor:
                 self.metrics['worker_utilization'] = active_workers / self.max_workers
                 
             except asyncio.CancelledError:
-                log.info("Batch processor loop cancelled")
+                log.debug("Batch processor loop cancelled")
                 break
             except Exception as e:
                 log.error(f"Error in batch processor loop: {e}")
                 await asyncio.sleep(1.0)
         
-        log.info("Batch processor loop stopped")
+        log.debug("Batch processor loop stopped")
     
     async def _monitor_loop(self) -> None:
         """
         Background monitoring loop for metrics and health checks.
         """
-        log.info("Monitor loop started")
+        log.debug("Monitor loop started")
         
         while self.workers_running:
             try:
@@ -447,13 +453,13 @@ class EnhancedStreamProcessor:
                         self.worker_tasks[i] = new_task
                 
             except asyncio.CancelledError:
-                log.info("Monitor loop cancelled")
+                log.debug("Monitor loop cancelled")
                 break
             except Exception as e:
                 log.error(f"Error in monitor loop: {e}")
                 await asyncio.sleep(1.0)
         
-        log.info("Monitor loop stopped")
+        log.debug("Monitor loop stopped")
     
     def get_status(self) -> Dict[str, Any]:
         """
@@ -505,6 +511,42 @@ class EnhancedStreamProcessor:
                 self.event_callbacks[event_type].remove(callback)
             except ValueError:
                 pass  # Callback not found
+    
+    async def _start_tunnel_telemetry_collection(self):
+        """Start tunnel telemetry collection parallel to stream processing."""
+        try:
+            from vrouter_agent.telemetry.tunnel_telemetry import TunnelTelemetryCollector
+            import vrouter_agent.telemetry.tunnel_telemetry as telemetry_module
+            
+            if telemetry_module.tunnel_telemetry_collector is None:
+                log.debug("Initializing tunnel telemetry collector at application startup...")
+                telemetry_module.tunnel_telemetry_collector = TunnelTelemetryCollector()
+                await telemetry_module.tunnel_telemetry_collector.start_metrics_collection()
+                log.debug("Successfully started tunnel telemetry collection parallel to stream processing")
+            else:
+                log.debug("Tunnel telemetry collector already exists")
+                # Ensure metrics collection is running
+                if not telemetry_module.tunnel_telemetry_collector._metrics_collection_running:
+                    await telemetry_module.tunnel_telemetry_collector.start_metrics_collection()
+                    log.debug("Restarted tunnel telemetry metrics collection")
+                    
+        except Exception as e:
+            log.warning(f"Failed to start tunnel telemetry collection: {e}")
+            # Don't raise - telemetry failures shouldn't break the application
+    
+    async def _stop_tunnel_telemetry_collection(self):
+        """Stop tunnel telemetry collection."""
+        try:
+            import vrouter_agent.telemetry.tunnel_telemetry as telemetry_module
+            
+            if telemetry_module.tunnel_telemetry_collector is not None:
+                await telemetry_module.tunnel_telemetry_collector.stop_metrics_collection()
+                log.debug("Stopped tunnel telemetry collection")
+            else:
+                log.debug("Tunnel telemetry collector was not initialized")
+                
+        except Exception as e:
+            log.warning(f"Error stopping tunnel telemetry collection: {e}")
 
 
 # Global instance management
