@@ -1231,7 +1231,7 @@ class VRouterClient:
         interface: Interface,
         frr_container_name: str = "frr",
     ):
-        lcp = f"sudo vppctl lcp create {interface.interface_name} host-if {interface.interface_name} netns {frr_container_name} tun"
+        lcp = f"vppctl lcp create {interface.interface_name} host-if {interface.interface_name} netns {frr_container_name} tun"
         _, ret1 = run_command(lcp.split())
         if ret1 == 0:
             log.debug(f"Created LCP interface: {interface.interface_name}")
@@ -1239,7 +1239,7 @@ class VRouterClient:
             log.error(f"Error creating LCP interface: {interface.interface_name}")
             return False
 
-        ip_addr_del = f"sudo vppctl set interface ip address del {interface.interface_name} {str(interface.ip_address)}/{interface.prefix_len}"
+        ip_addr_del = f"vppctl set interface ip address del {interface.interface_name} {str(interface.ip_address)}/{interface.prefix_len}"
         _, ret2 = run_command(ip_addr_del.split())
 
         if ret2 == 0:
@@ -1248,7 +1248,7 @@ class VRouterClient:
             log.error(f"Error deleting IP address from interface: {interface.interface_name}")
             return False
 
-        set_ip = f"sudo vppctl set interface ip address {interface.interface_name} {str(interface.ip_address)}/{interface.prefix_len}"
+        set_ip = f"vppctl set interface ip address {interface.interface_name} {str(interface.ip_address)}/{interface.prefix_len}"
         _, ret3 = run_command(set_ip.split())
 
         if ret3 == 0:
