@@ -239,6 +239,8 @@ class MultichainNotifier:
             "tunnel_counts": tunnel_counts,
             "tunnel_details": tunnel_details,
             "frr_enabled": bool(tunnel_config.frr_config),
+            "nat_enabled": bool(tunnel_config.nat_config) and tunnel_config.nat_config.get("enabled", False) if tunnel_config.nat_config else False,
+            "acl_enabled": bool(tunnel_config.acl_config) and tunnel_config.acl_config.get("enabled", False) if tunnel_config.acl_config else False,
             "ospf_enabled": tunnel_config.ospf_enabled,
             "ebgp_enabled": tunnel_config.ebgp_enabled,
             "client_interfaces_count": len(tunnel_config.client_interfaces) if tunnel_config.client_interfaces else 0,
