@@ -57,7 +57,7 @@ class VRouterClient:
         self.frr_config = frr_config
         self.lcp_global = lcp_global
         
-        log.info(f"VRouterClient initialized with {len(tunnels)} tunnel configs")
+        log.debug(f"VRouterClient initialized with {len(tunnels)} tunnel configs")
     
     @property
     def wireguard(self) -> WireGuardTunnelManager:
@@ -342,29 +342,23 @@ class VRouterClient:
     
     # NAT Configuration Methods
     
-    def add_nat_configuration(self, lan_iface, wan_iface, wg_ports_to_open: List[int],
-                             tcp_ports: List[int] = None, udp_ports: List[int] = None) -> bool:
+    def add_nat_configuration(self, nat_config) -> bool:
         """
         Add NAT configuration for LAN/WAN interfaces.
         
         Args:
-            lan_iface: LAN interface (Interface object or dict)
-            wan_iface: WAN interface (Interface object or dict)
-            wg_ports_to_open: WireGuard ports to open
-            tcp_ports: Additional TCP ports to open
-            udp_ports: Additional UDP ports to open
+            nat_config: NAT configuration (NatConfig object or dict)
             
         Returns:
             bool: True if configuration successful, False otherwise
         """
         try:
-            return self.nat.configure_nat(
-                lan_interface=lan_iface,
-                wan_interface=wan_iface,
-                wg_ports_to_open=wg_ports_to_open,
-                tcp_ports=tcp_ports or [],
-                udp_ports=udp_ports or []
-            )
+            # Convert dict to NatConfig if needed
+            if isinstance(nat_config, dict):
+                from vrouter_agent.schemas.nat_acl_config import NatConfig
+                nat_config = NatConfig.from_dict(nat_config)
+            
+            return self.nat.configure_nat(nat_config=nat_config)
         except Exception as e:
             log.error(f"Exception adding NAT configuration: {e}")
             return False
@@ -398,22 +392,19 @@ class VRouterClient:
     
     # ACL Configuration Methods
     
-    def add_acl_configuration(self, ingress_iface, deny_network: str) -> bool:
+    def add_acl_configuration(self, acl_config) -> bool:
         """
-        Add ACL configuration to deny specific network.
+        Add ACL configuration.
         
         Args:
-            ingress_iface: Ingress interface (Interface object or dict)
-            deny_network: Network to deny (CIDR notation)
+            acl_config: ACL configuration (AclConfig object or dict)
             
         Returns:
             bool: True if configuration successful, False otherwise
         """
         try:
-            return self.acl.configure_acl(
-                ingress_interface=ingress_iface,
-                deny_network=deny_network
-            )
+            # Let ACL manager handle all conversions (supports both firewall and VPP formats)
+            return self.acl.configure_acl_from_config(acl_config=acl_config)
         except Exception as e:
             log.error(f"Exception adding ACL configuration: {e}")
             return False
