@@ -11,11 +11,13 @@ import ipaddress
 
 from loguru import logger as log
 from vpp_vrouter.common import models
+from vrouter_agent.core.config import get_primary_interface
+from vrouter_agent.schemas.nat_acl_config import NatConfig
 
 from ..base_interfaces import SecurityManager, create_result_dict
 from ..connection.vpp_connection import VPPConnectionManager
 from ...core.base import Interface
-
+from ...core.config import settings
 
 class NATManager(SecurityManager):
     """
@@ -66,98 +68,151 @@ class NATManager(SecurityManager):
         
         return errors
 
-    def configure_nat(self, lan_interface: Interface, wan_interface: Interface,
-                     wg_ports_to_open: List[int], tcp_ports: List[int] = None,
-                     udp_ports: List[int] = None) -> bool:
+    def configure_nat(self, nat_config: NatConfig) -> bool:
         """
-        Configure NAT44 for LAN/WAN interfaces with port mappings.
+        Configure NAT44 for LAN/WAN interfaces with address pools and port mappings.
         
         Args:
-            lan_interface: LAN interface configuration
-            wan_interface: WAN interface configuration  
-            wg_ports_to_open: WireGuard ports to open (UDP)
-            tcp_ports: Additional TCP ports to open
-            udp_ports: Additional UDP ports to open
+            nat_config: NatConfig schema object containing NAT configuration
             
         Returns:
             bool: True if configuration successful, False otherwise
         """
         try:
-            tcp_ports = tcp_ports or []
-            udp_ports = udp_ports or []
+            if not nat_config.enabled:
+                log.info("NAT configuration is disabled, skipping")
+                return True
+
+            log.info("Starting NAT configuration")
+
+            primary_wan = get_primary_interface(type='wan')
+            primary_lan = get_primary_interface(type='lan')
+         
+            # Create NAT interface configurations from schema
+            nat_interfaces = []
             
-            policy_name = f"nat-{lan_interface.interface_name}-{wan_interface.interface_name}"
+            if nat_config.nat44_interfaces:
+                # Use interfaces from the schema
+                for iface in nat_config.nat44_interfaces:
+                    nat_interfaces.append(
+                        models.Nat44InterfaceConfigurationItem(
+                            name=iface.name,
+                            nat_inside=iface.nat_inside,
+                            nat_outside=iface.nat_outside,
+                            output_feature=iface.output_feature,
+                        )
+                    )
+            else:
+                # Fallback to default LAN/WAN configuration
+                nat_interfaces.extend([
+                    models.Nat44InterfaceConfigurationItem(
+                        name=primary_lan.interface_name,
+                        nat_inside=True,
+                        nat_outside=False,
+                        output_feature=False,
+                    ),
+                    models.Nat44InterfaceConfigurationItem(
+                        name=primary_wan.interface_name,
+                        nat_inside=False,
+                        nat_outside=True,
+                        output_feature=False,
+                    )
+                ])
             
-            log.info(f"Configuring NAT policy '{policy_name}' for {lan_interface.interface_name} -> {wan_interface.interface_name}")
+            # Create NAT pool addresses from schema
+            pool_addresses = []
+            if nat_config.address_pools:
+                for i, pool in enumerate(nat_config.address_pools):
+                    # If last_ip is empty, use first_ip (single IP pool)
+                    last_ip = pool.last_ip if pool.last_ip else pool.first_ip
+                    
+                    pool_addresses.append(
+                        models.Nat44AddressPoolConfigurationItem(
+                            name=pool.name or f"nat-pool-{i}",
+                            first_ip=ipaddress.IPv4Address(pool.first_ip),
+                            last_ip=ipaddress.IPv4Address(last_ip),
+                        )
+                    )
             
-            # Create NAT interface configurations
-            lan_nat_iface = models.Nat44InterfaceConfigurationItem(
-                name=lan_interface.interface_name,
-                nat_inside=True,
-                nat_outside=False,
-                output_feature=False,
-            )
+            # Create static mappings and identity mappings from schema
+            static_mappings = []
+            identity_mappings = []
             
-            wan_nat_iface = models.Nat44InterfaceConfigurationItem(
-                name=wan_interface.interface_name,
-                nat_inside=False,
-                nat_outside=True,
-                output_feature=False,
-            )
-            
-            # Create address pool
-            nat_address_pool = models.Nat44AddressPoolConfigurationItem(
-                name="nat-pool",
-                first_ip=ipaddress.IPv4Address(wan_interface.ip_address),
-                last_ip=ipaddress.IPv4Address(wan_interface.ip_address),
-            )
-            
-            # Create port mappings
-            wg_port_mappings = [
-                models.IdentityMapping(
-                    interface=wan_interface.interface_name,
-                    protocol=models.ProtocolInNAT.UDP,
-                    port=port,
-                )
-                for port in wg_ports_to_open
-            ]
-            
-            tcp_port_mappings = [
-                models.IdentityMapping(
-                    interface=wan_interface.interface_name,
-                    protocol=models.ProtocolInNAT.TCP,
-                    port=port,
-                )
-                for port in tcp_ports
-            ]
-            
-            udp_port_mappings = [
-                models.IdentityMapping(
-                    interface=wan_interface.interface_name,
-                    protocol=models.ProtocolInNAT.UDP,
-                    port=port,
-                )
-                for port in udp_ports
-            ]
+            if nat_config.dnat:
+                # Process static mappings
+                if nat_config.dnat.static_mappings:
+                    for mapping in nat_config.dnat.static_mappings:
+                        # Convert schema LocalIP objects to VPP models.LocalIP objects
+                        local_ips = [
+                            models.LocalIP(
+                                local_ip=ipaddress.IPv4Address(lip.local_ip),
+                                local_port=lip.local_port,
+                                probability=lip.probability
+                            ) 
+                            for lip in mapping.local_ips
+                        ]
+                        
+                        # Determine external_ip and external_interface
+                        # Note: VPP library has a bug where external_sw_if_index=0 maps to local0
+                        # Even when using explicit IP, we need to provide a valid interface name
+                        # VPP will use external_ip when both are provided (IP takes precedence)
+                        if mapping.external_ip and mapping.external_ip != "0.0.0.0" and mapping.external_ip != "":
+                            # Use explicit external IP with WAN interface as reference
+                            external_interface = primary_wan.interface_name  # Provide valid interface to avoid local0
+                            external_ip = ipaddress.IPv4Address(mapping.external_ip)
+                            log.info(f"NAT static mapping: Using explicit external_ip={external_ip} with interface={external_interface}")
+                            
+                            static_mappings.append(
+                                models.StaticMapping(
+                                    external_interface=external_interface,
+                                    external_ip=external_ip,
+                                    external_port=mapping.external_port,
+                                    local_ips=local_ips,
+                                    protocol=models.ProtocolInNAT(mapping.protocol),
+                                )
+                            )
+                        else:
+                            # Use WAN interface to get IP dynamically
+                            external_interface = mapping.external_interface or primary_wan.interface_name
+                            external_ip = ipaddress.IPv4Address(str(primary_wan.ip_address))
+                            log.info(f"NAT static mapping: Using external_interface={external_interface}, external_ip={external_ip}")
+                            
+                            static_mappings.append(
+                                models.StaticMapping(
+                                    external_interface=external_interface,
+                                    external_ip=external_ip,
+                                    external_port=mapping.external_port,
+                                    local_ips=local_ips,
+                                    protocol=models.ProtocolInNAT(mapping.protocol),
+                                )
+                            )
+                
+                # Process identity mappings
+                if nat_config.dnat.identity_mappings:
+                    for mapping in nat_config.dnat.identity_mappings:
+                        identity_mappings.append(
+                            models.IdentityMapping(
+                                interface=mapping.interface or primary_wan.interface_name,
+                                port=mapping.port,
+                                protocol=models.ProtocolInNAT(mapping.protocol)
+                            )
+                        )
             
             # Create NAT mappings configuration
-            nat_mappings = models.DNat44ConfigurationItem(
-                label="nat-mappings",
-                static_mappings=[],
-                identity_mappings=list(chain(
-                    wg_port_mappings, 
-                    tcp_port_mappings, 
-                    udp_port_mappings
-                )),
-            )
+            nat_mappings = None
+            if static_mappings or identity_mappings:
+                nat_mappings = models.DNat44ConfigurationItem(
+                    label=nat_config.dnat.label if nat_config.dnat and nat_config.dnat.label else "nat-mappings",
+                    static_mappings=static_mappings,
+                    identity_mappings=identity_mappings
+                )
             
             # Apply configuration to VPP
-            reply = self.connection.client.add_configuration(
-                lan_nat_iface,
-                wan_nat_iface,
-                nat_address_pool,
-                nat_mappings,
-            )
+            configs_to_add = nat_interfaces + pool_addresses
+            if nat_mappings:
+                configs_to_add.append(nat_mappings)
+            
+            reply = self.connection.client.add_configuration(*configs_to_add)
             
             errors = self._extract_reply_errors(reply)
             if errors:
@@ -166,15 +221,15 @@ class NATManager(SecurityManager):
                 return False
             
             # Store policy information for management
+            policy_name = f"nat-{primary_lan.interface_name}-{primary_wan.interface_name}"
             self.active_policies[policy_name] = {
-                'lan_interface': lan_interface.interface_name,
-                'wan_interface': wan_interface.interface_name,
-                'wg_ports': wg_ports_to_open,
-                'tcp_ports': tcp_ports,
-                'udp_ports': udp_ports,
-                'created_at': self._get_current_timestamp()
+                'enabled': nat_config.enabled,
+                'lan_interface': primary_lan.interface_name,
+                'wan_interface': primary_wan.interface_name,
+                'created_at': self._get_current_timestamp(),
+                'nat_config': nat_config  # Store the full config for reference
             }
-            
+
             log.info(f"NAT configuration '{policy_name}' applied successfully")
             return True
             
@@ -257,37 +312,25 @@ class NATManager(SecurityManager):
         Create a NAT policy from configuration.
         
         Args:
-            policy_config: NAT policy configuration
+            policy_config: NAT policy configuration dictionary or NatConfig object
             
         Returns:
             dict: Creation result
         """
         try:
-            # Extract configuration parameters
-            lan_iface_config = policy_config.get('lan_interface')
-            wan_iface_config = policy_config.get('wan_interface')
-            ports_config = policy_config.get('ports', {})
+            # If it's already a NatConfig object, use it directly
+            if isinstance(policy_config, NatConfig):
+                nat_config = policy_config
+            else:
+                # Convert dictionary to NatConfig object
+                nat_config = NatConfig.from_dict(policy_config)
             
-            if not lan_iface_config or not wan_iface_config:
-                return create_result_dict(
-                    success=False, 
-                    error="Missing required interface configurations"
-                )
+            # Configure NAT using the schema object
+            success = self.configure_nat(nat_config)
             
-            # Convert to Interface objects
-            lan_interface = self._dict_to_interface(lan_iface_config)
-            wan_interface = self._dict_to_interface(wan_iface_config)
-            
-            # Configure NAT
-            success = self.configure_nat(
-                lan_interface=lan_interface,
-                wan_interface=wan_interface,
-                wg_ports_to_open=ports_config.get('wireguard', []),
-                tcp_ports=ports_config.get('tcp', []),
-                udp_ports=ports_config.get('udp', [])
-            )
-            
-            policy_name = f"nat-{lan_interface.interface_name}-{wan_interface.interface_name}"
+            primary_wan = get_primary_interface(type='wan')
+            primary_lan = get_primary_interface(type='lan')
+            policy_name = f"nat-{primary_lan.interface_name}-{primary_wan.interface_name}"
             
             if success:
                 return create_result_dict(
@@ -335,21 +378,60 @@ class NATManager(SecurityManager):
         
         try:
             policy = self.active_policies[policy_name]
+            nat_config = policy.get('nat_config')
             
-            # Create Interface objects from stored data
-            lan_interface = Interface(interface_name=policy['lan_interface'])
-            wan_interface = Interface(interface_name=policy['wan_interface'])
+            # Get current VPP configuration
+            current_config = self.connection.client.get_configuration()
+            configs_to_remove = []
             
-            # Remove the NAT configuration
-            success = self.remove_nat_configuration(
-                lan_interface=lan_interface,
-                wan_interface=wan_interface,
-                wg_ports_to_open=policy['wg_ports'],
-                tcp_ports=policy['tcp_ports'],
-                udp_ports=policy['udp_ports']
-            )
+            # Find NAT interfaces to remove
+            nat_interfaces = [
+                item.config
+                for item in current_config.items
+                if isinstance(item.config, models.Nat44InterfaceConfigurationItem)
+                and item.config.name in [policy['lan_interface'], policy['wan_interface']]
+            ]
+            configs_to_remove.extend(nat_interfaces)
             
-            return success
+            # Find address pools to remove
+            if nat_config and nat_config.address_pools:
+                pool_names = [pool.name or f"nat-pool-{i}" for i, pool in enumerate(nat_config.address_pools)]
+                address_pools = [
+                    item.config
+                    for item in current_config.items
+                    if isinstance(item.config, models.Nat44AddressPoolConfigurationItem)
+                    and item.config.name in pool_names
+                ]
+                configs_to_remove.extend(address_pools)
+            
+            # Find DNAT mappings to remove
+            if nat_config and nat_config.dnat:
+                dnat_items = [
+                    item.config
+                    for item in current_config.items
+                    if isinstance(item.config, models.DNat44ConfigurationItem)
+                ]
+                configs_to_remove.extend(dnat_items)
+            
+            if not configs_to_remove:
+                log.warning(f"No configurations found to remove for policy '{policy_name}'")
+                del self.active_policies[policy_name]
+                return True
+            
+            # Remove configurations from VPP
+            reply = self.connection.client.delete_configuration(*configs_to_remove)
+            
+            errors = self._extract_reply_errors(reply)
+            if errors:
+                for error in errors:
+                    log.error(f"Error deleting NAT configuration: {error}")
+                return False
+            
+            # Remove from active policies
+            del self.active_policies[policy_name]
+            
+            log.info(f"NAT configuration '{policy_name}' removed successfully")
+            return True
             
         except Exception as e:
             log.error(f"Exception removing NAT policy '{policy_name}': {e}")
@@ -369,33 +451,53 @@ class NATManager(SecurityManager):
         """Get status of NAT policy."""
         if identifier in self.active_policies:
             policy = self.active_policies[identifier]
-            return {
+            nat_config = policy.get('nat_config')
+            
+            status = {
                 'name': identifier,
                 'status': 'active',
                 'lan_interface': policy['lan_interface'],
                 'wan_interface': policy['wan_interface'],
-                'ports': {
-                    'wireguard': policy['wg_ports'],
-                    'tcp': policy['tcp_ports'],
-                    'udp': policy['udp_ports']
-                },
                 'created_at': policy['created_at']
             }
+            
+            # Add NAT config details if available
+            if nat_config:
+                status['enabled'] = nat_config.enabled
+                status['address_pools_count'] = len(nat_config.address_pools) if nat_config.address_pools else 0
+                status['nat44_interfaces_count'] = len(nat_config.nat44_interfaces) if nat_config.nat44_interfaces else 0
+                
+                if nat_config.dnat:
+                    status['static_mappings_count'] = len(nat_config.dnat.static_mappings) if nat_config.dnat.static_mappings else 0
+                    status['identity_mappings_count'] = len(nat_config.dnat.identity_mappings) if nat_config.dnat.identity_mappings else 0
+            
+            return status
         else:
             return {'name': identifier, 'status': 'not_found'}
     
     def list_components(self) -> List[Dict[str, Any]]:
         """List all active NAT policies."""
-        return [
-            {
+        result = []
+        for name, policy in self.active_policies.items():
+            nat_config = policy.get('nat_config')
+            component = {
                 'name': name,
                 'status': 'active',
                 'lan_interface': policy['lan_interface'],
-                'wan_interface': policy['wan_interface'],
-                'port_count': len(policy['wg_ports']) + len(policy['tcp_ports']) + len(policy['udp_ports'])
+                'wan_interface': policy['wan_interface']
             }
-            for name, policy in self.active_policies.items()
-        ]
+            
+            # Add counts if nat_config is available
+            if nat_config:
+                pool_count = len(nat_config.address_pools) if nat_config.address_pools else 0
+                static_count = len(nat_config.dnat.static_mappings) if nat_config.dnat and nat_config.dnat.static_mappings else 0
+                identity_count = len(nat_config.dnat.identity_mappings) if nat_config.dnat and nat_config.dnat.identity_mappings else 0
+                component['mapping_count'] = static_count + identity_count
+                component['pool_count'] = pool_count
+            
+            result.append(component)
+        
+        return result
     
     # Public utility methods
     
@@ -407,15 +509,26 @@ class NATManager(SecurityManager):
             dict: NAT statistics
         """
         try:
-            # This would implement actual NAT statistics retrieval from VPP
-            # For now, return basic information
+            # Calculate statistics from active policies
+            total_pools = 0
+            total_static_mappings = 0
+            total_identity_mappings = 0
+            
+            for policy in self.active_policies.values():
+                nat_config = policy.get('nat_config')
+                if nat_config:
+                    total_pools += len(nat_config.address_pools) if nat_config.address_pools else 0
+                    if nat_config.dnat:
+                        total_static_mappings += len(nat_config.dnat.static_mappings) if nat_config.dnat.static_mappings else 0
+                        total_identity_mappings += len(nat_config.dnat.identity_mappings) if nat_config.dnat.identity_mappings else 0
+            
             return {
                 'active_policies': len(self.active_policies),
                 'policies': list(self.active_policies.keys()),
-                'total_ports_mapped': sum(
-                    len(policy['wg_ports']) + len(policy['tcp_ports']) + len(policy['udp_ports'])
-                    for policy in self.active_policies.values()
-                )
+                'total_address_pools': total_pools,
+                'total_static_mappings': total_static_mappings,
+                'total_identity_mappings': total_identity_mappings,
+                'total_mappings': total_static_mappings + total_identity_mappings
             }
             
         except Exception as e:
@@ -437,6 +550,7 @@ class NATManager(SecurityManager):
         
         try:
             policy = self.active_policies[policy_name]
+            nat_config = policy.get('nat_config')
             
             # Check if NAT interfaces are configured in VPP
             current_config = self.connection.client.get_configuration()
@@ -448,25 +562,34 @@ class NATManager(SecurityManager):
                 and item.config.name in [policy['lan_interface'], policy['wan_interface']]
             ]
             
-            # Check port mappings
-            all_ports = set(policy['wg_ports'] + policy['tcp_ports'] + policy['udp_ports'])
-            port_mappings = [
-                item.config
-                for item in current_config.items
-                if isinstance(item.config, models.IdentityMapping)
-                and item.config.port in all_ports
-            ]
+            # Check address pools
+            pool_count = 0
+            if nat_config and nat_config.address_pools:
+                address_pools = [
+                    item.config
+                    for item in current_config.items
+                    if isinstance(item.config, models.Nat44AddressPoolConfigurationItem)
+                ]
+                pool_count = len(address_pools)
             
-            interfaces_ok = len(nat_interfaces) == 2
-            ports_ok = len(port_mappings) >= len(all_ports)
+            # Check mappings
+            static_mappings_count = 0
+            identity_mappings_count = 0
+            if nat_config and nat_config.dnat:
+                static_mappings_count = len(nat_config.dnat.static_mappings) if nat_config.dnat.static_mappings else 0
+                identity_mappings_count = len(nat_config.dnat.identity_mappings) if nat_config.dnat.identity_mappings else 0
+            
+            interfaces_ok = len(nat_interfaces) >= 1  # At least one interface should be configured
+            pools_ok = pool_count >= len(nat_config.address_pools) if nat_config and nat_config.address_pools else True
             
             return {
-                'verified': interfaces_ok and ports_ok,
+                'verified': interfaces_ok and pools_ok,
                 'interfaces_configured': interfaces_ok,
-                'ports_configured': ports_ok,
+                'pools_configured': pools_ok,
                 'interface_count': len(nat_interfaces),
-                'port_mapping_count': len(port_mappings),
-                'expected_ports': len(all_ports)
+                'pool_count': pool_count,
+                'static_mappings_count': static_mappings_count,
+                'identity_mappings_count': identity_mappings_count
             }
             
         except Exception as e:
