@@ -188,7 +188,7 @@ class StreamListener:
     
     async def _listener_loop(self) -> None:
         """Main listener loop that continuously polls the stream for new items."""
-        log.info("Stream listener loop started")
+        log.debug("Stream listener loop started")
         
         # Initial startup delay to allow system initialization
         await asyncio.sleep(self.config.startup_delay)
