@@ -690,13 +690,13 @@ class GRETunnelManager(TunnelManager):
         try:
             # Add multicast routes for OSPF
             run_command([
-                "sudo", "vppctl", "ip", "mroute", "add",
+                "vppctl", "ip", "mroute", "add",
                 remote_ip, "224.0.0.5",
                 "via", gre_name, "Accept"
             ])
             
             run_command([
-                "sudo", "vppctl", "ip", "mroute", "add",
+                "vppctl", "ip", "mroute", "add",
                 remote_ip, "224.0.0.5",
                 "via", "local", "Forward"
             ])
@@ -730,7 +730,7 @@ class GRETunnelManager(TunnelManager):
     def _check_gre_interface_status(self, interface_name: str) -> bool:
         """Check if GRE interface is up."""
         try:
-            cmd = f"sudo vppctl show interface {interface_name}"
+            cmd = f"vppctl show interface {interface_name}"
             res, _ = run_command(cmd.split())
             
             return interface_name in res and "up" in res.lower() and "down" not in res.lower()
@@ -743,7 +743,7 @@ class GRETunnelManager(TunnelManager):
         """Test connectivity through GRE tunnel."""
         try:
             # Simple ping test through the GRE interface
-            cmd = f"sudo vppctl ping {self._safe_extract_ip(peer_ip)} repeat 1"
+            cmd = f"vppctl ping {self._safe_extract_ip(peer_ip)} repeat 1"
             res, _ = run_command(cmd.split())
             
             return "1 sent, 1 received" in res
