@@ -88,12 +88,12 @@ class WireGuardTunnelManager(TunnelManager):
             log.info(f"Processing WireGuard configs in sorted order: {[cfg.get('interface_name', cfg.get('name', 'unknown')) for cfg in sorted_configs]}")
             
             # Validate configurations
-            validation_result = self._validate_tunnel_configs(sorted_configs)
-            if not validation_result['valid']:
-                return create_result_dict(
-                    success=False, 
-                    error=f"Configuration validation failed: {validation_result['errors']}"
-                )
+            # validation_result = self._validate_tunnel_configs(sorted_configs)
+            # if not validation_result['valid']:
+            #     return create_result_dict(
+            #         success=False, 
+            #         error=f"Configuration validation failed: {validation_result['errors']}"
+            #     )
             
             # Convert to WireGuardConfig objects and sort them
             self._tunnel_configs = [self._dict_to_wireguard_config(config) for config in sorted_configs]
@@ -332,6 +332,34 @@ class WireGuardTunnelManager(TunnelManager):
             log.warning(f"Could not check existing WireGuard interfaces: {e}")
             return start_index
     
+    def get_existing_wireguard_ports(self) -> Dict[int, str]:
+        """
+        Get dictionary of existing WireGuard interface ports and their associated interfaces.
+        
+        Returns:
+            Dict[int, str]: Mapping of port number to interface name
+        """
+        existing_ports = {}
+        try:
+            current_config = self.connection.client.get_configuration()
+            
+            for item in current_config.items:
+                if (hasattr(item.config, 'type') and 
+                    hasattr(models.InterfaceType, 'WIREGUARD_TUNNEL') and
+                    item.config.type == models.InterfaceType.WIREGUARD_TUNNEL):
+                    
+                    if hasattr(item.config, 'link') and hasattr(item.config.link, 'port'):
+                        port = item.config.link.port
+                        if port:
+                            existing_ports[port] = item.config.name
+                            
+            log.debug(f"Existing WireGuard ports: {existing_ports}")
+            return existing_ports
+            
+        except Exception as e:
+            log.warning(f"Could not check existing WireGuard interface ports: {e}")
+            return {}
+    
     def get_wireguard_interfaces(self) -> List[Dict[str, Any]]:
         """
         Get list of all WireGuard interfaces from VPP.
@@ -352,9 +380,14 @@ class WireGuardTunnelManager(TunnelManager):
                         'name': item.config.name,
                         'enabled': getattr(item.config, 'enabled', False),
                         'ip_addresses': getattr(item.config, 'ip_addresses', []),
-                        'mtu': getattr(item.config, 'mtu', None)
+                        'mtu': getattr(item.config, 'mtu', None),
+                        # render all object attributes as strings
+                        'additional_attributes': {k: str(v) for k, v in item.config.__dict__.items() if k not in ['name', 'type', 'enabled', 'ip_addresses', 'mtu', 'link']}
                     }
                     
+                    
+                   
+
                     # Add WireGuard-specific link information
                     if hasattr(item.config, 'link') and item.config.link:
                         link = item.config.link
@@ -408,10 +441,40 @@ class WireGuardTunnelManager(TunnelManager):
         required_fields = ['address', 'private_key', 'peer_public_key', 'peer_address']
         all_errors = []
         
+        # Check for port conflicts among new configurations
+        port_usage = {}
+        
+        # Check for port conflicts with existing interfaces
+        existing_ports = self.get_existing_wireguard_ports()
+        
         for i, config in enumerate(configs):
+            # Basic field validation
             result = validate_component_config(config, required_fields)
             if not result['valid']:
                 all_errors.extend([f"Config {i}: {error}" for error in result['errors']])
+            
+            # Check for port conflicts
+            listen_port = config.get('listen_port')
+            if listen_port:
+                # Check against existing VPP interfaces
+                if listen_port in existing_ports:
+                    all_errors.append(
+                        f"Port conflict: Config {i} wants to use port {listen_port} but it's already used by interface {existing_ports[listen_port]}"
+                    )
+                # Check against other new configurations
+                elif listen_port in port_usage:
+                    all_errors.append(
+                        f"Port conflict: Config {i} and Config {port_usage[listen_port]} both use listen_port {listen_port}"
+                    )
+                else:
+                    port_usage[listen_port] = i
+            else:
+                all_errors.append(f"Config {i}: Missing required field 'listen_port'")
+        
+        if port_usage:
+            log.info(f"New port assignments: {port_usage}")
+        if existing_ports:
+            log.info(f"Existing port assignments: {existing_ports}")
         
         return {
             'valid': len(all_errors) == 0,
@@ -430,13 +493,23 @@ class WireGuardTunnelManager(TunnelManager):
         peers = []
         routes = []
         
+        # First pass: resolve and store all interface names to avoid conflicts
+        for i, tunnel_config in enumerate(self._tunnel_configs):
+            if not tunnel_config.interface_name:
+                # Generate interface name based on index
+                tunnel_config.interface_name = f"wg{i}"
+                log.debug(f"Generated interface name: {tunnel_config.interface_name} for tunnel {i}")
+            else:
+                log.debug(f"Using provided interface name: {tunnel_config.interface_name} for tunnel {i}")
         
-        for tunnel_config in self._tunnel_configs:
+        # Second pass: create VPP configurations with resolved names
+        for i, tunnel_config in enumerate(self._tunnel_configs):
+            log.debug(f"Processing tunnel config {i}: interface_name={tunnel_config.interface_name}, listen_port={tunnel_config.listen_port}")
             
             # Interface configuration
             interfaces.append(
                 models.InterfaceConfigurationItem(
-                    name=tunnel_config.interface_name or f"wg{self.get_next_available_index()}",
+                    name=tunnel_config.interface_name,
                     type=models.InterfaceType.WIREGUARD_TUNNEL,
                     enabled=True,
                     ip_addresses=[f"{tunnel_config.address}/30"],
@@ -452,7 +525,7 @@ class WireGuardTunnelManager(TunnelManager):
             # Peer configuration
             peers.append(
                 models.WireguardPeerConfigurationItem(
-                    wg_if_name=tunnel_config.interface_name or f"wg{self.get_next_available_index()}",
+                    wg_if_name=tunnel_config.interface_name,
                     public_key=tunnel_config.peer_public_key,
                     allowed_ips=["0.0.0.0/0"],
                     persistent_keepalive=tunnel_config.persistent_keepalive,
@@ -466,7 +539,7 @@ class WireGuardTunnelManager(TunnelManager):
                 models.RouteConfigurationItem(
                     destination_network=f"{tunnel_config.peer_address.split('/')[0]}/32",
                     next_hop_address=tunnel_config.address.split("/")[0],
-                    outgoing_interface= tunnel_config.interface_name or f"wg{self.get_next_available_index()}",
+                    outgoing_interface=tunnel_config.interface_name,
                 )
             )
             
@@ -509,14 +582,13 @@ class WireGuardTunnelManager(TunnelManager):
     def _create_tunnel_tracking_objects(self) -> List[CreatedWireguardTunnel]:
         """Create tunnel tracking objects for internal management."""
         created_tunnels = []        
-        for i, tunnel_config in enumerate(self._tunnel_configs):
-            
+        for tunnel_config in self._tunnel_configs:
             created_tunnels.append(
                 CreatedWireguardTunnel(
-                    name=tunnel_config.interface_name or f"wg{self.get_next_available_index()}",
+                    name=tunnel_config.interface_name,
                     ip_address=tunnel_config.address,
                     peer_ip_address=tunnel_config.peer_address,
-                    mapped_name=tunnel_config.interface_name if tunnel_config.interface_name else None,
+                    mapped_name=tunnel_config.interface_name,
                 )
             )
         
