@@ -9,6 +9,7 @@ This implementation has been refactored to simplify the code and improve maintai
 """
 
 import asyncio
+import time
 from datetime import datetime
 from typing import Dict, Any, List, Optional, Tuple
 from loguru import logger as log
@@ -23,11 +24,13 @@ from vrouter_agent.models.tunnel_config import (
 from vrouter_agent.schemas.tunnel_config import (
     TunnelConfigData as TunnelConfigSchema
 )
+from vrouter_agent.schemas.nat_acl_config import convert_nat_config, convert_acl_config
 from vrouter_agent.core.enums import StreamItemAction
 from vrouter_agent.core.base import CreatedWireguardTunnel
 from vrouter_agent.services.refactored_client import VRouterClient
 from vrouter_agent.services.multichain_notifier import send_tunnel_status_notification
 from vrouter_agent.core.config import get_primary_interface, settings
+from vrouter_agent.telemetry import tunnel_telemetry_collector, TunnelStatus, TunnelType
 
 class TunnelOperations:
     """
@@ -176,6 +179,70 @@ class TunnelOperations:
                 if tunnel_config.frr_config:
                     await self._apply_frr_configuration(client, tunnel_config)
                 
+                # Handle NAT configuration if present
+                if tunnel_config.nat_config:
+                    log.debug(f"NAT config details: {tunnel_config.nat_config}")
+                    
+                    # Add identity mappings for WireGuard ports to allow tunnel traffic
+                    nat_config = tunnel_config.nat_config
+                    if nat_config.get('enabled', True):
+                        # Collect WireGuard ports from tunnels
+                        wg_ports = set()
+                        for tunnel in tunnels:
+                            if 'listen_port' in tunnel and tunnel['listen_port']:
+                                wg_ports.add(int(tunnel['listen_port']))
+                        
+                        # Add identity mappings for WireGuard ports (UDP protocol)
+                        if wg_ports:
+                            from vrouter_agent.schemas.nat_acl_config import NatConfig, IdentityMapping, ProtocolInNAT
+                            
+                            # Convert dict to NatConfig if needed
+                            if isinstance(nat_config, dict):
+                                nat_config_obj = NatConfig.from_dict(nat_config)
+                            else:
+                                nat_config_obj = nat_config
+                            
+                            # Ensure dnat section exists
+                            if not nat_config_obj.dnat:
+                                from vrouter_agent.schemas.nat_acl_config import DNat44
+                                nat_config_obj.dnat = DNat44(label="nat-mappings", identity_mappings=[])
+                            
+                            # Add identity mappings for each WireGuard port
+                            for port in wg_ports:
+                                identity_mapping = IdentityMapping(
+                                    interface="",  # Will use WAN interface by default in nat_manager
+                                    port=port,
+                                    protocol=ProtocolInNAT.UDP  # WireGuard uses UDP
+                                )
+                                nat_config_obj.dnat.identity_mappings.append(identity_mapping)
+                                log.info(f"Added identity mapping for WireGuard port {port} (UDP)")
+                            
+                            # Apply NAT configuration with identity mappings
+                            nat_success = client.add_nat_configuration(nat_config=nat_config_obj)
+                        else:
+                            # No WireGuard ports found, apply NAT as-is
+                            nat_success = client.add_nat_configuration(nat_config=nat_config)
+                    else:
+                        nat_success = client.add_nat_configuration(nat_config=nat_config)
+                    
+                    if not nat_success:
+                        log.error("Failed to apply NAT configuration")
+                        success = False
+                    else:
+                        log.info("NAT configuration applied successfully")
+                
+                # Handle ACL configuration if present
+                log.debug(f"Applying ACL configuration: {tunnel_config.acl_config}")
+                if tunnel_config.acl_config:
+                    # Apply ACL configuration - conversion handled in ACL manager
+                    acl_success = client.add_acl_configuration(acl_config=tunnel_config.acl_config)
+                    
+                    if not acl_success:
+                        log.error("Failed to apply ACL configuration")
+                        success = False
+                    else:
+                        log.info("ACL configuration applied successfully")
+
                 # Store interface information
                 await self._store_interface_mappings(tunnel_config, interfaces, client, event)
                 
@@ -221,6 +288,24 @@ class TunnelOperations:
                 if tunnel_config.frr_config:
                     await self._apply_frr_configuration(client, tunnel_config)
                 
+                # Handle NAT configuration if present
+                # log.debug(f"Applying NAT configuration: {tunnel_config.nat_config}")
+                # if tunnel_config.nat_config:
+                #     nat_success = client.add_nat_configuration(nat_config=tunnel_config.nat_config)
+                #     if not nat_success:
+                #         log.error("Failed to apply NAT configuration")
+                #         success = False
+                #     else:
+                #         log.info("NAT configuration applied successfully")
+                # # Handle ACL configuration if present
+                # if tunnel_config.acl_config:
+                #     acl_success = client.add_acl_configuration(acl_config=tunnel_config.acl_config)
+                #     if not acl_success:
+                #         log.error("Failed to apply ACL configuration")
+                #         success = False
+                #     else:
+                #         log.info("ACL configuration applied successfully")
+                
                 # Verify tunnel states
                 await self._verify_tunnel_states(client, tunnel_config, event)
                 
@@ -263,6 +348,15 @@ class TunnelOperations:
 
                 if success:
                     log.info(f"Successfully removed WireGuard tunnels for {tunnel_config.order_id}")
+                    
+                    # Record telemetry for deleted tunnels
+                    for tunnel_data in tunnel_config.tunnels_data:
+                        self._record_tunnel_telemetry(
+                            tunnel_data, 
+                            TunnelStatus.DOWN, 
+                            tunnel_config,
+                            {'interface_up': False, 'operational': False, 'connectivity_test': False}
+                        )
                    
                 else:
                     log.error(f"Failed to remove WireGuard tunnels for {tunnel_config.order_id}")
@@ -328,7 +422,12 @@ class TunnelOperations:
                         peer.get('lan_interface_ip'),
                         primary_lan.interface_name
                     )
-       
+                # add neighbour info for the client loopback as well - for namespace routing
+                client.utility.add_client_neighbour_info(
+                        primary_lan.interface_name,
+                        peer.get('peer_ip'),
+                        peer.get('lan_mac_address')
+                    )
         # Apply FRR config and add routes
         client.utility.apply_frr_configuration(tunnel_config.frr_config)
         
@@ -361,7 +460,7 @@ class TunnelOperations:
                         'vpp_up': False,
                         'vpp_operational': False,
                         'vpp_connectivity_test_passed': False,
-                        'vpp_created_at': datetime.now().isoformat()
+                        'vpp_created_at': time.time()
                     }
             
             # Update tunnel data with interface information
@@ -434,6 +533,14 @@ class TunnelOperations:
                 if result.get('operational', False):
                     tunnel_copy['state'] = TunnelState.ACTIVE
                     log.info(f"Tunnel {interface_name} is active")
+                    
+                    # Record tunnel as UP in telemetry
+                    self._record_tunnel_telemetry(
+                        tunnel_copy, 
+                        TunnelStatus.UP, 
+                        tunnel_config, 
+                        result
+                    )
                 else:
                     tunnel_copy['state'] = TunnelState.PENDING
                     issue = 'unknown reasons'
@@ -442,6 +549,18 @@ class TunnelOperations:
                     elif not result.get('connectivity_test', False):
                         issue = 'connectivity test failed'
                     log.warning(f"Tunnel {interface_name} is pending - {issue}")
+                    
+                    # Record tunnel as DOWN in telemetry
+                    tunnel_status = TunnelStatus.DOWN
+                    if not result.get('interface_up', False):
+                        tunnel_status = TunnelStatus.ERROR
+                    
+                    self._record_tunnel_telemetry(
+                        tunnel_copy, 
+                        tunnel_status, 
+                        tunnel_config, 
+                        result
+                    )
                 
                 # Add history record for state change
                 if old_state != tunnel_copy['state']:
@@ -780,6 +899,8 @@ class TunnelOperations:
             existing_config.topology_id = config_data.get("topology", {}).get("id") if config_data.get("topology") else None
             existing_config.topology_data = config_data.get("topology", {})
             existing_config.frr_config = config_data.get("frr_config")
+            existing_config.nat_config = config_data.get("nat_config")
+            existing_config.acl_config = config_data.get("acl_config")
             existing_config.client_interfaces = config_data.get("client_interfaces", [])
             existing_config.bgp_peers = config_data.get("bgp_peers", [])
             existing_config.ospf_enabled = config_data.get("ospf_enabled", False)
@@ -801,6 +922,8 @@ class TunnelOperations:
             topology_data=config_data.get("topology", {}),
             tunnels_data=config_data.get("tunnels", []),
             frr_config=config_data.get("frr_config"),
+            nat_config=config_data.get("nat_config"),
+            acl_config=config_data.get("acl_config"),
             client_interfaces=config_data.get("client_interfaces", []),
             bgp_peers=config_data.get("bgp_peers", []),
             ospf_enabled=config_data.get("ospf_enabled", False),
@@ -831,6 +954,72 @@ class TunnelOperations:
             
         return tunnel_config.tunnels_data
     
+    def _record_tunnel_telemetry(
+        self, 
+        tunnel_data: Dict[str, Any], 
+        status: TunnelStatus,
+        tunnel_config: TunnelConfigModel,
+        verification_result: Dict[str, Any]
+    ) -> None:
+        """
+        Record tunnel telemetry data for Splunk ingestion and API retrieval.
+        
+        Args:
+            tunnel_data: Tunnel configuration data
+            status: Current tunnel status
+            tunnel_config: Parent tunnel configuration
+            verification_result: VPP verification results
+        """
+        try:
+            # Import and check telemetry collector
+            import vrouter_agent.telemetry.tunnel_telemetry as telemetry_module
+            if telemetry_module.tunnel_telemetry_collector is None:
+                log.debug("Tunnel telemetry collector not initialized, skipping telemetry recording")
+                return
+            
+            # Prepare telemetry data
+            telemetry_data = {
+                'name': tunnel_data.get('interface_name', 'unknown'),
+                'type': 'wireguard',  # Default to wireguard, could be determined from config
+                'local_ip': tunnel_data.get('vpp_ip_address'),
+                'remote_ip': tunnel_data.get('peer_endpoint_address'),
+                'peer_endpoint': tunnel_data.get('peer_endpoint'),
+                'interface_index': tunnel_data.get('vpp_interface_index'),
+                'order_id': tunnel_config.order_id,
+                'order_number': tunnel_config.order_number,
+                'topology_id': tunnel_config.topology_id,
+                'config_version': str(tunnel_config.config_version),
+                'created_at': tunnel_data.get('vpp_created_at'),
+                
+                # Add VPP-specific data
+                'vpp_up': verification_result.get('interface_up', False),
+                'vpp_operational': verification_result.get('operational', False),
+                'connectivity_test_passed': verification_result.get('connectivity_test', False),
+                
+                # Add custom tags for better categorization
+                'tags': [
+                    f"order:{tunnel_config.order_number}" if tunnel_config.order_number else None,
+                    f"topology:{tunnel_config.topology_id}" if tunnel_config.topology_id else None,
+                    f"action:{tunnel_config.action}" if tunnel_config.action else None,
+                    "vpp_verified",
+                    "automated_monitoring"
+                ]
+            }
+            
+            # Filter out None tags
+            telemetry_data['tags'] = [tag for tag in telemetry_data['tags'] if tag is not None]
+            
+            # Record the telemetry using the module reference
+            telemetry_module.tunnel_telemetry_collector.record_tunnel_status(
+                tunnel_id=tunnel_data.get('interface_name', 'unknown'),
+                status=status,
+                tunnel_data=telemetry_data
+            )
+            log.debug(f"Recorded tunnel telemetry: {tunnel_data.get('interface_name')} -> {status.value}")
+            
+        except Exception as e:
+            log.error(f"Error recording tunnel telemetry: {e}")
+            # Don't raise - telemetry failures shouldn't break tunnel operations
+    
 
-                    
 
